( cd opt/kde/share/doc/HTML/de/kivio ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kivio ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kugar ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kugar ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kword ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kword ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/koffice ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/koffice ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/koshell ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/koshell ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kspread ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kspread ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kchart ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kchart ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kpresenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kpresenter ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/thesaurus ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/thesaurus ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kformula ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kformula ; ln -sf /opt/kde/share/doc/HTML/de/common common )
